@@ -1,16 +1,15 @@
+imports.gi.versions.Gtk = '3.0';
+imports.gi.versions.WebKit2 = '4.0';
 const Gtk = imports.gi.Gtk;
-const WebKit = imports.gi.WebKit;
+const WebKit = imports.gi.WebKit2;
 
 Gtk.init(null);
 
 let win = new Gtk.Window();
 
-let sw = new Gtk.ScrolledWindow({});
-win.add(sw);
-
 let view = new WebKit.WebView();
 view.load_uri("http://www.google.com/");
-sw.add(view);
+win.add(view);
 
 win.set_size_request(640, 480);
 win.show_all();
